meegkit.detrend
===============

.. automodule:: meegkit.detrend

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      detrend
      reduce_ringing
      regress
   
   

   
   
   

   
   
   



